@@ -7,13 +7,13 @@ import string
 import sys
 
 from tomahawk import (
-    __version__
+    __version__,
+    TimeoutError,
 )
 from tomahawk.color import (
     create_coloring_object
 )
 from tomahawk.constants import (
-    TimeoutError,
     DEFAULT_TIMEOUT,
     DEFAULT_COMMAND_OUTPUT_FORMAT,
     DEFAULT_EXPECT_DELAY,
@@ -40,7 +40,11 @@ class BaseMain(object):
         self.script_path = script_path
         self.arg_parser = self.create_argument_parser(script_path)
         self.options = self.arg_parser.parse_args()
-        self.log = create_logger(self.options.debug or self.options.deep_debug, self.options.deep_debug)
+        self.log = create_logger(
+            None,
+            self.options.debug or self.options.deep_debug,
+            self.options.deep_debug
+        )
 
     def run(self):
         try:
