@@ -39,7 +39,7 @@ class CommandMain(BaseMain):
         self.log.debug("arguments = " + str(self.options.command))
 
     def do_run(self):
-        context = CommandContext(
+        self.context = CommandContext(
             self.options.command,
             self.options.__dict__,
             sys.stdout,
@@ -52,11 +52,11 @@ class CommandMain(BaseMain):
         # prompt when production environment
         self.confirm_execution_on_production(
             'Command "%s" will be executed to %s hosts. Are you sure? [yes/NO]: '
-            % (color.green(' '.join(context.arguments)), color.green(len(hosts)))
+            % (color.green(' '.join(self.context.arguments)), color.green(len(hosts)))
         )
 
-        executor = CommandExecutor(context, self.log, hosts)
-        return executor.execute(context.arguments)
+        executor = CommandExecutor(self.context, self.log, hosts)
+        return executor.execute(self.context.arguments)
 
     @classmethod
     def create_argument_parser(cls, file):
@@ -145,7 +145,12 @@ class CommandExecutor(BaseExecutor):
                     command_args.append(option.strip())
 
                 command_args.append(host)
-                c = command.replace('"', '\\"')
+                # Escape shell special chars
+                c = command.replace('\\', '\\\\') \
+                        .replace('"', '\"') \
+                        .replace('$', '\$') \
+                        .replace('`', '\`')
+
                 # execute a command with shell because we want to use pipe(|) and so on.
                 command_args.extend([ '/bin/sh', '-c', '"%s"' % (c) ])
 
