@@ -17,20 +17,33 @@ class CommandWithExpect(object):
     """
     A command executor through expect.
     """
-    def __init__(self, command, command_args, login_password, sudo_password,
-                 timeout = DEFAULT_TIMEOUT, expect_delay = DEFAULT_EXPECT_DELAY, debug_enabled = False):
-        self.command = command
-        self.command_args = command_args
+    def __init__(
+        self, command, command_args, login_password, sudo_password,
+        timeout = DEFAULT_TIMEOUT, expect_delay = DEFAULT_EXPECT_DELAY,
+        debug_enabled = False, expect = None,
+        expect_out = cStringIO.StringIO()
+    ):
         self.login_password = login_password
         self.sudo_password = sudo_password
         self.timeout = timeout
         self.expect_delay = expect_delay
-        self.log = create_logger(debug_enabled)
+        self.log = create_logger(None, debug_enabled)
         self.expect_patterns = [
             '^Enter passphrase.+',
             '[Pp]assword.*:',
             'パスワード', # TODO: japanese character expected as utf-8
         ]
+        if expect is None:
+            self.expect = pexpect.spawn(
+                command,
+                command_args,
+                timeout = timeout,
+                logfile = expect_out
+            )
+        else:
+            self.expect = expect
+        self.expect_out = expect_out
+        self.log.debug("command = %s, command_args = %s" % (command, str(command_args)))
 
     def execute(self):
         """
@@ -38,17 +51,9 @@ class CommandWithExpect(object):
         
         Returns: command result status, output string
         """
-        expect_output = cStringIO.StringIO()
-        child = pexpect.spawn(
-            self.command,
-            self.command_args,
-            timeout = self.timeout,
-            logfile = expect_output
-        )
-        self.log.debug("command = %s, args = %s" % (self.command, str(self.command_args)))
 
         try:
-            index = child.expect(self.expect_patterns)
+            index = self.expect.expect(self.expect_patterns)
             self.log.debug("expect index = %d" % (index))
             password = self.login_password or self.sudo_password
             if index in (0, 1, 2):
@@ -58,16 +63,16 @@ class CommandWithExpect(object):
                     raise CommandError("Password is empty. Use -l/--prompt-login-password or --login-password-stdin.")
 
                 if index == 0:
-                    child.sendline(self.login_password) # for ssh passphrase
+                    self.expect.sendline(self.login_password) # for ssh passphrase
                 else:
-                    child.sendline(password)
-                index2 = child.expect(self.expect_patterns)
+                    self.expect.sendline(password)
+                index2 = self.expect.expect(self.expect_patterns)
                 self.log.debug("expect index2 = %d" % (index2))
                 if index2 == 0:
-                    child.sendline(self.login_password) # for ssh passphrase
+                    self.expect.sendline(self.login_password) # for ssh passphrase
                 else:
-                    child.sendline(password)
-                child.expect(pexpect.EOF)
+                    self.expect.sendline(password)
+                self.expect.expect(pexpect.EOF)
             if index == 3:
                 self.log.debug("expect.EOF")
         except pexpect.TIMEOUT:
@@ -78,9 +83,9 @@ class CommandWithExpect(object):
         except CommandError, e:
             raise e, None, sys.exc_info()[2]
 
-        return self.get_status_and_output(child, expect_output)
+        return self.get_status_and_output(self.expect, self.expect_out)
 
-    def get_status_and_output(self, child, expect_output):
+    def get_status_and_output(self, child, expect_out):
         # Need a litte bit sleep because of failure of expect
         time.sleep(self.expect_delay)
         child.close()
@@ -100,14 +105,15 @@ class CommandWithExpect(object):
             passwords.append(self.login_password)
         if self.sudo_password:
             passwords.append(self.sudo_password)
-        for line in expect_output.getvalue().split('\n'):
+        for line in expect_out.getvalue().split('\n'):
             line = line.strip('\r\n')
             if line == '' or line in passwords:
                 continue
 
             for password in passwords:
                 # for debug output
-                line = line.replace(password, len(password) * '*')
+                if line == password:
+                    line = line.replace(password, len(password) * '*')
             self.log.debug("line = " + line)
 
             append = True
